@@ -6,12 +6,17 @@ sub search {
     my $self = shift;
     my $isbn = shift;
 
-    if($isbn ne '123456789X') {
+    if($isbn eq '9780987654328') {
         $self->found(0);
         $self->book(undef);
         return;
     }
 
+    if($isbn eq '9790571239589') {
+        $self->handler('Website unavailable');
+        return;
+    }
+
     my $bk = {
         isbn    => $isbn,
         title   => 'test title',
